==> aws-cdk.aws-ivs-alpha-2.5.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_ivs_alpha_LatencyMode(p) {
}
function _aws_cdk_aws_ivs_alpha_ChannelType(p) {
}
function _aws_cdk_aws_ivs_alpha_PlaybackKeyPairProps(p) {
}
function _aws_cdk_aws_ivs_alpha_StreamKeyProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.channel))
        _aws_cdk_aws_ivs_alpha_IChannel(p.channel);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_alpha_IPlaybackKeyPair(p) {
}
function _aws_cdk_aws_ivs_alpha_IStreamKey(p) {
}
function _aws_cdk_aws_ivs_alpha_IChannel(p) {
}
function _aws_cdk_aws_ivs_alpha_ChannelProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.latencyMode))
        _aws_cdk_aws_ivs_alpha_LatencyMode(p.latencyMode);
    if (!visitedObjects.has(p.type))
        _aws_cdk_aws_ivs_alpha_ChannelType(p.type);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_alpha_StreamKey(p) {
}
function _aws_cdk_aws_ivs_alpha_PlaybackKeyPair(p) {
}
function _aws_cdk_aws_ivs_alpha_Channel(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_ivs_alpha_LatencyMode, _aws_cdk_aws_ivs_alpha_ChannelType, _aws_cdk_aws_ivs_alpha_PlaybackKeyPairProps, _aws_cdk_aws_ivs_alpha_StreamKeyProps, _aws_cdk_aws_ivs_alpha_IPlaybackKeyPair, _aws_cdk_aws_ivs_alpha_IStreamKey, _aws_cdk_aws_ivs_alpha_IChannel, _aws_cdk_aws_ivs_alpha_ChannelProps, _aws_cdk_aws_ivs_alpha_StreamKey, _aws_cdk_aws_ivs_alpha_PlaybackKeyPair, _aws_cdk_aws_ivs_alpha_Channel };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-ivs-alpha-2.17.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_ivs_alpha_LatencyMode(p) {
}
function _aws_cdk_aws_ivs_alpha_ChannelType(p) {
}
function _aws_cdk_aws_ivs_alpha_PlaybackKeyPairProps(p) {
}
function _aws_cdk_aws_ivs_alpha_StreamKeyProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.channel))
        _aws_cdk_aws_ivs_alpha_IChannel(p.channel);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_alpha_IPlaybackKeyPair(p) {
}
function _aws_cdk_aws_ivs_alpha_IStreamKey(p) {
}
function _aws_cdk_aws_ivs_alpha_IChannel(p) {
}
function _aws_cdk_aws_ivs_alpha_PlaybackKeyPair(p) {
}
function _aws_cdk_aws_ivs_alpha_ChannelProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.latencyMode))
        _aws_cdk_aws_ivs_alpha_LatencyMode(p.latencyMode);
    if (!visitedObjects.has(p.type))
        _aws_cdk_aws_ivs_alpha_ChannelType(p.type);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_ivs_alpha_StreamKey(p) {
}
function _aws_cdk_aws_ivs_alpha_Channel(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_ivs_alpha_LatencyMode, _aws_cdk_aws_ivs_alpha_ChannelType, _aws_cdk_aws_ivs_alpha_PlaybackKeyPairProps, _aws_cdk_aws_ivs_alpha_StreamKeyProps, _aws_cdk_aws_ivs_alpha_IPlaybackKeyPair, _aws_cdk_aws_ivs_alpha_IStreamKey, _aws_cdk_aws_ivs_alpha_IChannel, _aws_cdk_aws_ivs_alpha_PlaybackKeyPair, _aws_cdk_aws_ivs_alpha_ChannelProps, _aws_cdk_aws_ivs_alpha_StreamKey, _aws_cdk_aws_ivs_alpha_Channel };
module.exports.DeprecationError = DeprecationError;
